Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(152)

Unified Diff: third_party/WebKit/Source/bindings/core/v8/ScriptStreamer.cpp

Issue 2820753002: Revert of Split PendingScript into PendingScript and ClassicPendingScript (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/bindings/core/v8/ScriptStreamer.cpp
diff --git a/third_party/WebKit/Source/bindings/core/v8/ScriptStreamer.cpp b/third_party/WebKit/Source/bindings/core/v8/ScriptStreamer.cpp
index ff214f59ce1d9930f455de2fd51ccb77d188d0ef..ed43b25ead964d0c04c40365213ceae7ebea5042 100644
--- a/third_party/WebKit/Source/bindings/core/v8/ScriptStreamer.cpp
+++ b/third_party/WebKit/Source/bindings/core/v8/ScriptStreamer.cpp
@@ -7,9 +7,9 @@
#include <memory>
#include "bindings/core/v8/ScriptStreamerThread.h"
#include "bindings/core/v8/V8ScriptRunner.h"
-#include "core/dom/ClassicPendingScript.h"
#include "core/dom/Document.h"
#include "core/dom/Element.h"
+#include "core/dom/PendingScript.h"
#include "core/frame/Settings.h"
#include "core/html/parser/TextResourceDecoder.h"
#include "core/loader/resource/ScriptResource.h"
@@ -325,7 +325,7 @@
size_t ScriptStreamer::small_script_threshold_ = 30 * 1024;
-void ScriptStreamer::StartStreaming(ClassicPendingScript* script,
+void ScriptStreamer::StartStreaming(PendingScript* script,
Type script_type,
Settings* settings,
ScriptState* script_state,
@@ -515,7 +515,7 @@
}
ScriptStreamer::ScriptStreamer(
- ClassicPendingScript* script,
+ PendingScript* script,
Type script_type,
ScriptState* script_state,
v8::ScriptCompiler::CompileOptions compile_options,
@@ -579,7 +579,7 @@
}
bool ScriptStreamer::StartStreamingInternal(
- ClassicPendingScript* script,
+ PendingScript* script,
Type script_type,
Settings* settings,
ScriptState* script_state,
@@ -598,7 +598,7 @@
if (resource->IsCacheValidator()) {
RecordNotStreamingReasonHistogram(script_type, kReload);
// This happens e.g., during reloads. We're actually not going to load
// the current Resource of the ClassicPendingScript but switch to another
// Resource -> don't stream.
return false;
}
@@ -613,8 +613,8 @@
if (settings->GetV8CacheOptions() == kV8CacheOptionsParse)
compile_option = v8::ScriptCompiler::kProduceParserCache;
// The Resource might go out of scope if the script is no longer needed.
// This makes ClassicPendingScript notify the ScriptStreamer when it is
// destroyed.
script->SetStreamer(ScriptStreamer::Create(script, script_type, script_state,
compile_option,
@@ -598,7 +598,7 @@
RecordNotStreamingReasonHistogram(script_type, kReload);
// This happens e.g., during reloads. We're actually not going to load
- // the current Resource of the ClassicPendingScript but switch to another
+ // the current Resource of the PendingScript but switch to another
// Resource -> don't stream.
return false;
@@ -613,8 +613,8 @@
if (settings->GetV8CacheOptions() == kV8CacheOptionsParse)
compile_option = v8::ScriptCompiler::kProduceParserCache;
- // The Resource might go out of scope if the script is no longer needed.
- // This makes ClassicPendingScript notify the ScriptStreamer when it is
+ // The Resource might go out of scope if the script is no longer
+ // needed. This makes PendingScript notify the ScriptStreamer when it is
// destroyed.
script->SetStreamer(ScriptStreamer::Create(script, script_type, script_state,

Powered by Google App Engine
This is Rietveld 408576698